# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .thread_batch_stop_result_item import ThreadBatchStopResultItem


class ThreadBatchStopResponseOut(UniversalBaseModel):
    """
    Response model for batch thread stop.
    """

    failed_count: int = pydantic.Field()
    """
    Number of threads that failed to stop
    """

    results: typing.List[ThreadBatchStopResultItem] = pydantic.Field()
    """
    Detailed results for each thread
    """

    stopped_count: int = pydantic.Field()
    """
    Number of threads successfully stopped
    """

    total_requested: int = pydantic.Field()
    """
    Total number of threads requested to stop
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
